#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class MerchantTransfer(BaseObject):
	"""
	
	"""

	__config = {
		
		"fea532ff-c18d-4a12-94fc-55b882907fc3" : OperationConfig("/send/v1/partners/{partnerId}/merchant/transfer", "create", [], []),
		
		"f9529ffa-e122-4b41-bed4-bead7872edc7" : OperationConfig("/send/v1/partners/{partnerId}/merchant/transfers/{transferId}", "read", [], []),
		
		"6062e2ae-7862-4e11-8370-52863a049d67" : OperationConfig("/send/v1/partners/{partnerId}/merchant/transfers", "query", [], ["ref"]),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUI)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative())


	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type MerchantTransfer

		@param Dict mapObj, containing the required parameters to create a new object
		@return MerchantTransfer of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("fea532ff-c18d-4a12-94fc-55b882907fc3", MerchantTransfer(mapObj))










	@classmethod
	def readByID(cls,id,criteria=None):
		"""
		Returns objects of type MerchantTransfer by id and optional criteria
		@param str id
		@param dict criteria
		@return instance of MerchantTransfer
		@raise ApiException: raised an exception from the response status
		"""
		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if criteria:
			if (isinstance(criteria,RequestMap)):
				mapObj.setAll(criteria.getObject())
			else:
				mapObj.setAll(criteria)

		return BaseObject.execute("f9529ffa-e122-4b41-bed4-bead7872edc7", MerchantTransfer(mapObj))







	@classmethod
	def readByReference(cls,criteria):
		"""
		Query objects of type MerchantTransfer by id and optional criteria
		@param type criteria
		@return MerchantTransfer object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("6062e2ae-7862-4e11-8370-52863a049d67", MerchantTransfer(criteria))


